Learn R Programming

smsets (version 2.0.0)

print.Levenetests2s.mv: Prints multiple two-sample Levene tests for the comparison of variation in multivariate data

Description

Prints the results produced by Levenetests2s.mv, consisting of two-sample Levene's tests computed from two-sample t-tests applied to absolute differences around medians for more than one response vector.

Usage

# S3 method for Levenetests2s.mv
print(x, ...)

Value

An annotated output of two-sample Levene's tests computed from two-sample t-tests applied to absolute differences around medians for more than one response vector, with (optionally) corrected significance levels. The argument x, invisibly, as for all print methods, is a list of class "Levenetests2s.mv". This print method provides a user-friendly display of particular elements in x:

  • A description of the analysis.

  • The data frame analyzed.

  • The labels of the two-level group factor (samples), with an order determined by the user in the Levenetests2s.mv argument level1.

  • The t-based Levene's test results for each response variable; these include:

    • The variable name.

    • Sample medians classified by group levels.

    • Means and variances of sample absolute deviations from the median classified by group levels.

    • The value of the t-statistic, the degrees of freedom and the p-value.

    • Effect sizes: raw and Hedge's (1981). The units of raw effect sizes are shown according to the argument unit = in Levenetests2s.mv.

  • The type of alternative hypothesis for all tests.

  • The method of significance level adjustment for multiple comparisons used.

Arguments

x

an object of class "Levenetests2s.mv"

...

further arguments passed to or from other methods.

Details

Summarize

References

Hedges, L. V. 1981. Distribution theory for Glass’s estimator of effect size and related estimators. Journal of Educational Statistics 6(2): 107–128.

Examples

Run this code
data(sparrows)
res.Levene2s.mv <- Levenetests2s.mv(sparrows, Survivorship, "S",
                               alternative = "less", var.equal = TRUE,
                               P.adjust = "bonferroni", unit = "mm")
print(res.Levene2s.mv)

Run the code above in your browser using DataLab