Learn R Programming

smsets (version 2.0.0)

print.ttests2s.mv: Prints multiple two-sample t-tests for a multivariate data set

Description

Prints the results produced by ttests2s.mv, consisting of two-sample t-tests on more than one response vector with corrected significance levels for multiple comparisons, as offered by p.adjust. Effects sizes are also displayed.

Usage

# S3 method for ttests2s.mv
print(x, ...)

Value

An annotated output of multiple two-sample t-tests on more than one response vector with (optionally) corrected significance levels. The argument x, invisibly, as for all print methods, is a list of class "ttests2s.mv". This print method provides a user-friendly display of particular elements in x:

  • A description of the analysis.

  • The data frame analyzed.

  • The labels of the two-level group factor (samples), with an order determined by the user in the ttests2s.mv argument level1.

  • The t-test results for each response variable; these include:

    • The variable name.

    • Sample means and variances classified by group levels.

    • The value of the t-statistic, the degrees of freedom and the p-value.

    • Effect sizes: raw and Hedge's (1981). The units of raw effect sizes are shown according to the argument unit = in ttests2s.mv.

  • The type of alternative hypothesis for all tests.

  • The method of significance level adjustment for multiple comparisons used.

Arguments

x

an object of class "ttests2s.mv"

...

further arguments passed to or from other methods.

References

Hedges, L. V. 1981. Distribution theory for Glass’s estimator of effect size and related estimators. Journal of Educational Statistics 6(2): 107–128.

Examples

Run this code
data(sparrows)
ttests.sparrows <- ttests2s.mv(sparrows, group = Survivorship, level1 = "S",
                              var.equal = TRUE, P.adjust = "holm",
                              unit = "mm")
print(ttests.sparrows)

Run the code above in your browser using DataLab