Prints the results produced by Levenetestsms.mv,
consisting of m-sample Levene's tests computed from one-way ANOVAs
applied to absolute differences around medians for p responses. It
optionally produces a single multivariate Levene's test which is basically a
one-way MANOVA of absolute differences around medians.
# S3 method for Levenetestsms.mv
print(
x,
format = "oneway.test",
EffectSize = TRUE,
multivariate = FALSE,
mv_statistic = c("Pillai", "Wilks", "Hotelling-Lawley", "Roy"),
long = FALSE,
...
)An annotated output of m-sample Levene's tests computed from one-way
ANOVAs applied to absolute differences around medians for p responses,
with (optionally) corrected significance levels. The argument x,
invisibly, as for all print methods, is a list of class
"Levenetestsms.mv". This print method provides a user-friendly
display of particular elements in x:
A description of the analysis.
The data frame analyzed
The labels of the group factor with m levels (samples).
The univariate Levene's tests based on the results of one-way ANOVAs
for each response variable; These results consist of the F-tests
displayed in up to two different output formats corresponding to the
formatted results produced by the conventional functions
oneway.test and anova.lm.
P-values are recomputed whenever P.adjust method is different
from "none".
long = TRUE output lists:
Sample medians classified by group levels and variables.
Means and variances of sample absolute deviations from the median classified by group levels and variables.
multivariate = TRUE, the multivariate Levene's test is appended,
based on the test statistic specified in mv_statistic. If
multivariate = TRUE and mv_statistic is omitted, Pillai's
statistic is chosen by default.an object of class "Levenetestsms.mv".
a character string specifying the one-way ANOVA results are
formatted, must be one of "oneway.test" (default), "anova.lm"
or "both".
a logical variable. If TRUE (default), the measures
of effect size \(\eta^2\), \(\omega^2\), \(\epsilon^2\), and Cohen's f
are returned.
a logical variable. If TRUE, the multivariate
Levene's test is returned. The test statistic chosen can be set with the
optional argument mv_statistic.
a character string. The name of the test statistic to be
used in the multivariate Levene's test (any of the four tests implemented in
summary.manova). Pillai's test is the default. Partial
matching is used so the name can be abbreviated.
A logical variable indicating whether a long output is desired
(TRUE) or not (FALSE, the default). The additional objects
returned are three matrices: 1) matrix of medians for the original data
classified by sample and response variable, 2) matrix of mean absolute
deviations around means, and 3) matrix of variances of absolute deviations
around means.
further arguments passed to or from other methods.
data(skulls)
res.Levenems.mv <- Levenetestsms.mv(skulls, Period, var.equal = TRUE,
P.adjust = "bonferroni")
print(res.Levenems.mv, format = "both", multivariate = TRUE, long = TRUE)
Run the code above in your browser using DataLab