Displays Penrose's distances between m multivariate populations or samples.
The argument x, invisibly, as for all print methods, is a list of class
"Penrose.dist". This print method provides two sorts of output
depending on whether the long argument is TRUE or FALSE (the default).
The "short" output displays:
A heading describing the function.
The data frame analyzed.
The variables involved in the calculation of distances.
The factor defining the populations or samples and their levels.
The Penrose distance matrix (lower triangular form).
In addition to the above information, the "long" output lists:
The population or sample sizes.
The mean vector for each population / sample.
The covariance matrix for each population / sample
The pooled covariance matrix.